summaryrefslogtreecommitdiff
path: root/support-files/mysql-multi.server.sh
diff options
context:
space:
mode:
authorOtto Kekäläinen <otto@kekalainen.net>2020-06-11 01:39:11 +0300
committerRobert Bindar <robert@mariadb.org>2020-06-16 12:59:30 +0300
commit7803601dcb8e40746a10a4012b0c8eb08274db3e (patch)
treedd1a62a732fa38788a98abed41387f55cc101efd /support-files/mysql-multi.server.sh
parente290e5a75d0c2b12133c2ed118e3bc9bd26a266d (diff)
downloadmariadb-git-7803601dcb8e40746a10a4012b0c8eb08274db3e.tar.gz
MDEV-22569: Run bin/mariadbd instead of bin/mysqld
Replace all references to /usr/sbin/mysqld (and bin and libexec) with mariadbd, so that the binary server will always be 'mariadbd'. Also update all places that reference the server binary in other ways, such as AppArmor profiles and scripts that previously expected to find a 'mysqld' in process lists.
Diffstat (limited to 'support-files/mysql-multi.server.sh')
-rw-r--r--support-files/mysql-multi.server.sh16
1 files changed, 8 insertions, 8 deletions
diff --git a/support-files/mysql-multi.server.sh b/support-files/mysql-multi.server.sh
index f90d662fa8c..a7a51e6a095 100644
--- a/support-files/mysql-multi.server.sh
+++ b/support-files/mysql-multi.server.sh
@@ -50,7 +50,7 @@ then
exit 1
fi
-echo "mysqld $svr $mode"
+echo "mariadbd $svr $mode"
parse_arguments() {
for arg do
@@ -107,7 +107,7 @@ fi
datadir=@localstatedir@
basedir=
pid_file=
-parse_arguments `$print_defaults $defaults mysqld mysql_server mysql_multi_server`
+parse_arguments `$print_defaults $defaults mariadbd mysqld mysql_server mysql_multi_server`
if test -z "$basedir"
then
@@ -157,15 +157,15 @@ case "$mode" in
# root password.
if test -f "$pid_file"
then
- mysqld_pid=`cat $pid_file`
- echo "Killing mysqld $svr with pid $mysqld_pid"
- kill $mysqld_pid
- # mysqld should remove the pid_file when it exits, so wait for it.
+ mariadbd_pid=`cat $pid_file`
+ echo "Killing mariadbd $svr with pid $mariadbd_pid"
+ kill $mariadbd_pid
+ # mariadbd should remove the pid_file when it exits, so wait for it.
sleep 1
while [ -s $pid_file -a "$flags" != aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa ]
do
- [ -z "$flags" ] && echo "Wait for mysqld $svr to exit\c" || echo ".\c"
+ [ -z "$flags" ] && echo "Wait for mariadbd $svr to exit\c" || echo ".\c"
flags=a$flags
sleep 1
done
@@ -180,7 +180,7 @@ case "$mode" in
rm /var/lock/subsys/mysql
fi
else
- echo "No mysqld pid file found. Looked for $pid_file."
+ echo "No mariadbd pid file found. Looked for $pid_file."
fi
;;